==> zio-aws-macie2_2.13-5.17.104.12-sources.jar: zio/aws/macie2/model/SecurityHubConfiguration.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__boolean
import scala.jdk.CollectionConverters._
final case class SecurityHubConfiguration(
    publishClassificationFindings: __boolean,
    publishPolicyFindings: __boolean
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration = {
    import SecurityHubConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
      .builder()
      .publishClassificationFindings(
        __boolean.unwrap(publishClassificationFindings): java.lang.Boolean
      )
      .publishPolicyFindings(
        __boolean.unwrap(publishPolicyFindings): java.lang.Boolean
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly =
    zio.aws.macie2.model.SecurityHubConfiguration.wrap(buildAwsValue())
}
object SecurityHubConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.SecurityHubConfiguration =
      zio.aws.macie2.model.SecurityHubConfiguration(
        publishClassificationFindings,
        publishPolicyFindings
      )
    def publishClassificationFindings: __boolean
    def publishPolicyFindings: __boolean
    def getPublishClassificationFindings: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(publishClassificationFindings)
    def getPublishPolicyFindings: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(publishPolicyFindings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
  ) extends zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly {
    override val publishClassificationFindings: __boolean =
      zio.aws.macie2.model.primitives
        .__boolean(impl.publishClassificationFindings())
    override val publishPolicyFindings: __boolean =
      zio.aws.macie2.model.primitives.__boolean(impl.publishPolicyFindings())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
  ): zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.13-5.17.295.11-sources.jar: zio/aws/macie2/model/SecurityHubConfiguration.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__boolean
import scala.jdk.CollectionConverters._
final case class SecurityHubConfiguration(
    publishClassificationFindings: __boolean,
    publishPolicyFindings: __boolean
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration = {
    import SecurityHubConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
      .builder()
      .publishClassificationFindings(
        publishClassificationFindings: java.lang.Boolean
      )
      .publishPolicyFindings(publishPolicyFindings: java.lang.Boolean)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly =
    zio.aws.macie2.model.SecurityHubConfiguration.wrap(buildAwsValue())
}
object SecurityHubConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.SecurityHubConfiguration =
      zio.aws.macie2.model.SecurityHubConfiguration(
        publishClassificationFindings,
        publishPolicyFindings
      )
    def publishClassificationFindings: __boolean
    def publishPolicyFindings: __boolean
    def getPublishClassificationFindings: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(publishClassificationFindings)
    def getPublishPolicyFindings: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(publishPolicyFindings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
  ) extends zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly {
    override val publishClassificationFindings: __boolean =
      impl.publishClassificationFindings(): __boolean
    override val publishPolicyFindings: __boolean =
      impl.publishPolicyFindings(): __boolean
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.SecurityHubConfiguration
  ): zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly = new Wrapper(impl)
}
